Ebola: Healthcare worker in Glasgow contracts Ebola | Latest News | Breaking News UK and Newspaper content | Daily Star
Author: Cyrus Engineer
Description: A FEMALE healthcare worker who contracted Ebola after returning to Glasgow from Sierra Leone has been named.
Date: 2014-12-30

# Scot Ebola patient named: First pic of heroic nurse Pauline Cafferkey

A FEMALE healthcare worker who contracted Ebola after returning to Glasgow from Sierra Leone has been named.

By Cyrus Engineer & Sophie Alexander / Published 30th December 2014

TREATMENT: Pauline Cafferkey has been named as the Scottish Ebola patient [GETTY]

Pauline Cafferkey, a Scottish nurse, arrived at the Royal Free Hospital in Hampstead, north London, for specialist treatment at the infectious diseases unit this morning.

Ms Cafferkey returned to Scotland after working in the west African country and arrived on a British Airways flight at Glasgow airport at around 11.30pm on Sunday.

She has been a nurse for 16 years and was volunteering for Save The Children when she contracted the deadly virus.

Ms Cafferkey was said to be displaying no symptoms on the plane and the risk to other patients is said to be "low".

Public health officials are said to be looking to contact passengers who sat adjacent to the nurse as a precautionary approach.

Meanwhile, another person is being tested in north west Scotland for the virus but is said to be "low risk".

Another patient, in Truro, Cornwall, has been placed in isolation and is also being tested for Ebola.

The Scottish nurse was admitted to hospital early on Monday after feeling unwell. She is in a stable condition.

She was accompanied to hospital by a convoy of ambulances and police cars as workers wore full protective suits.

A tent has been set up around her bed so the infection can be contained while she is treated.

The unit in London successfully treated British nurse WIlliam Pooley who was flown home from Sierra Leone in August after contracting the virus.

ISOLATION: Roads were shut as the woman arrived for her flight to London [REUTERS]

Scotland's First Minister Nicola Sturgeon said: "Our first thoughts at this time must be with the patient diagnosed with Ebola and their friends and family. I wish them a speedy recovery.

"Scotland has been preparing for this possibility from the beginning of the outbreak in West Africa and I am confident that we are well prepared.

"We have the robust procedures in place to identify cases rapidly. Our health service also has the expertise and facilities to ensure that confirmed Ebola cases such as this are contained and isolated effectively minimising any potential spread of the disease.

"Scotland’s NHS has proved it is well able to cope with infectious diseases in the past, such as swine flu, and I am confident we will be able to respond effectively again.”

She has also spoken to Prime Minister David Cameron.

Health Secretary Jeremy Hunt, who chaired an emergency Cobra meeting, vowed the Government was doing "absolutely everything" to keep the public safe.

"We are reviewing our procedures and protocols for the other NHS workers who are working in Sierra Leone alongside colleagues from the Department for International Development and the Foreign Office," he said.

"They are doing a very, very brave job, under very challenging circumstances.

"We want to make absolutely sure that we are doing everything we can to keep them safe.

"The clinical advice is that the risk is very low to other passengers. She wasn't exhibiting feverish symptoms.

"The process has worked well because the moment she did exhibit those symptoms we were able to take her into isolation."

A British Airways spokesman said: "We are working closely with the health authorities in England and Scotland and will offer assistance with any information they require.

"Customers who flew from London Heathrow to Glasgow on BA1478 which departed at 2100 on Sunday December 28 and have concerns should contact the special number 08000 858531 set up by the Scottish Government.

"The safety and security of our customers and crew is always our top priority and the risk to people on board that individual flight is extremely low."

EMERGENCY: The Health Secretary Jeremy Hunt chaired a Cobra meeting following the news [GETTY]

> Ebola case. Public health experts have emphasised risks are negligible. Helpline for anyone on the Heathrow to Glasgow flight: 08000 858 531

> — Scottish Government (@scotgov) December 29, 2014

TREATMENT: The Gartnavel Hospital campus in Glasgow where the female healthcare worker is being cared for [AFP/GETTY]

The current Ebola outbreak, which began in West Africa, is the largest epidemic of the virus in history.

It began in Guinea in December 2013 and quickly spread to Liberia and Sierra Leone – the two worst-affected nations.

The World Health Organisation (WHO) has reported a total of 19,980 suspected cases and 7,793 deaths.

But the WHO believes these figures understate the true size of the deadly outbreak.

Earlier this month Time magazine named those healthcare workers who have travelled to help with the crisis as their "Person of the Year".

Anyone who was on the British Airways Heathrow to Glasgow flight on Sunday night is asked to call 08000 858531

Related articles

- 'They're going to be huge' Amy Childs thinks Ebola is a BAND who are 'amazing'
- EXCLUSIVE: MI5 fears Islamic State Ebola 'bomb'
- Chelsea hero Didier Drogba joins the fight against Ebola with video message
- Geldof's Band Aid song makes me cringe says Brit Ebola nurse
- 'They can f*** off': Bob Geldof hits back at Band Aid critics
- Queen has been 'deeply touched' by Ebola crisis as royals attend Christmas service

#### Celebs

More

##### That Strictly training paid off! Caroline Flack continues to flaunt bikini bod in Jamaica

CAROLINE Flack continued to raise the temperatures during her sun-soaked Jamaica getaway as she paraded her bikini body online.

##### SIZZLING celeb babes beat the January blues by jetting to warm...

##### Blonde bombshell Rita Ora is ready to spice up The Voice

##### Lose 840 pounds a week on Gwyneth's crazy new diet... That's £...

##### 'It's neither a crime, an insult or racist’ Madonna defends co...

##### Ray Winstone reveals his wardrobe fav: A pair of 15-year-old s...

##### ‘My time at A&E was not alcohol related’ Katie Hopkins in New ...

##### Next step nudist beach? Jodie Marsh continues boobylicious bik...

##### Baby joy for Corrie’s Kylie as actress Paula Lane welcomes fir...

##### Kim Kardashian sex tape co-star calls 911 in murder-suicide scare

##### RiRi's ripped! Rihanna flaunts sexy six-pack in teeny bikini

##### Happy NUDE year! Tara Reid shares completely starkers selfie

##### 'One Direction to lose fans & Kimye will split' Horseface Hopk...

##### Ex-lover snubs Cheryl in autobiography because he is still too...

##### Boyband Union J escape the cold to soak up some Barbados sunshine

##### Tequila & tashing on! Vicky Pattison flaunts cleavage & snogs ...

##### What would Dot Cotton say? EastEnders star poses topless in ra...

##### Guess who? Celeb couple look unrecognisable in NYE fancy dress

##### First kiss of 2015! Michelle Keegan & Mark Wright lock lips in...

##### WATCH: 'She sounds like a goat!' Glee star fails to hit high n...

##### Racing down the aisle! F1 ace Jenson Button marries model brid...

##### Red Hot! Bikini-clad Kimberley Garner flaunts toned beach body

##### 'The wh***s deserve a sh** life' Katie Price slams ex-BFFs as ...

##### Top model body! Kendall Jenner sizzles in skimpy bikini snap

##### WOW! Tulisa sizzles in the sand at the end of a tough year

##### 'I’m still close to ex Chris' Gwyneth admits it 'would have be...

##### New Year – same hot body! Sexy Luisa Zissman shows wild side i...

#### TOWIE

More

##### Baby on board? TOWIE’s Chloe Sims and Elliott Wright spark pregnancy rumours

TOWIE couple Chloe Sims and Elliott Wright have sparked rumours that they are expecting.

##### 'The sexiest move for a girl' Lucy Meck picks up gymnastics ti...

##### Shut up! Amy Childs dating TOWIE lothario Tom Pearce

##### Too hot to feel the cold! Sexy Jasmin Walia braves the cold in...

##### Towie lads get bodyguards to save them from female fans